@@ -6,7 +6,7 @@ ARGV[0] == '--send' or
   raise RuntimeError, 'This will send many mails! Are you sure? Tell me to "--send"'
 
 %w(debian-keyring-pgp debian-maintainers-pgp debian-nonupload-pgp .git).each do |ck|
-  Dir.exists?(ck) or raise RuntimeError, 'Please run this script from the base keyring-maint git tree'
+  Dir.exist?(ck) or raise RuntimeError, 'Please run this script from the base keyring-maint git tree'
 end
 
 data = `make test`.split(/\n/).select {|lin| lin=~/expired on/}
